Coverage for src/m6rclib/__init__.py: 100%

1"""An embedded compiler for the Metaphor language."""

2

3 __version__ = "0.1.0"

4

5# Export main classes so users can import directly from language_parser

6 from .metaphor_ast_node import MetaphorASTNode, MetaphorASTNodeType

7 from .metaphor_parser import MetaphorParser, MetaphorParserError

8

9# List what should be available when using `from language_parser import *`

10 __all__ = [

11 "MetaphorASTNode",

12 "MetaphorASTNodeType",

13 "MetaphorParser",

14 "MetaphorParserError",

15]